import os as _os
_base = _os.path.dirname(__file__)
for _entry in sorted(_os.listdir(_base)):
    _path = _os.path.join(_base, _entry)
    if _os.path.isdir(_path) and not _entry.startswith(('.', '_')):
        __path__.append(_path)

"""Utility modules: CLI, benchmarks, config, data, optimization."""

# Re-export commonly used names from wisent.core.utils.infra
# Many modules import these directly from wisent.core.utils
from wisent.core.utils.infra import (  # noqa: F401
    empty_device_cache,
    preferred_dtype,
    device_optimized_dtype,
    set_default_dtype,
    get_default_dtype,
    resolve_default_device,
    resolve_device,
    resolve_torch_device,
    ensure_tensor_on_device,
    move_module_to_preferred_device,
    STEERING_VECTOR_DTYPE,
    save_steering_vector,
    load_steering_vector,
    get_all_docs_from_task,
    create_deterministic_split,
    get_train_docs,
    get_test_docs,
    get_split_info,
    BaseRotator,
    get_layer_combinations,
    print_banner,
    render_banner,
    get_logo,
)

from wisent.core.utils.infra.core.layer_combinations import (  # noqa: F401
    get_layer_combinations_count,
)
