"""ArabCulture group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval.lm_task_extractors."

ARAB_CULTURE_TASKS = {
    "arabculture": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "ArabCulture": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_algeria": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_egypt": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_jordan": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_ksa": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_lebanon": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_libya": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_morocco": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_palestine": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_sudan": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_syria": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_tunisia": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_uae": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
    "arab_culture_yemen": f"{BASE_IMPORT}arabculture:ArabcultureExtractor",
}
