"""Display, visualization, and formatting constants."""
from wisent.core.utils.constants.cannot_be_optimized._infrastructure import *  # noqa: F401,F403

# --- Separator widths (print formatting) ---
SEPARATOR_WIDTH_COMPACT = 30
SEPARATOR_WIDTH_HALF = 35
SEPARATOR_WIDTH_NARROW = 40
SEPARATOR_WIDTH_MEDIUM = 50
SEPARATOR_WIDTH_MEDIUM_PLUS = 55
SEPARATOR_WIDTH_TABLE = 56
SEPARATOR_WIDTH_STANDARD = 60
SEPARATOR_WIDTH_PLUS = 65
SEPARATOR_WIDTH_WIDE = 70
SEPARATOR_WIDTH_WIDE_PLUS = 75
SEPARATOR_WIDTH_REPORT = 80
SEPARATOR_WIDTH_SENSITIVITY = 89
SEPARATOR_WIDTH_FULL = 100
SEPARATOR_WIDTH_ULTRA = 128
SEPARATOR_WIDTH_MAX = 150
SEPARATOR_PAD_SMALL = 20
# --- Display decimal precision ---
DISPLAY_DECIMAL_PRECISION = 2
# --- Display truncation ---
DISPLAY_TRUNCATION_SHORT = 50
DISPLAY_TRUNCATION_MEDIUM = 200
DISPLAY_TRUNCATION_LONG = 300
DISPLAY_TRUNCATION_DESCRIPTION = 25
DISPLAY_TRUNCATION_MODEL = 40
DISPLAY_TRUNCATION_TASK = 20
DISPLAY_TRUNCATION_XLARGE = 400
DISPLAY_TRUNCATION_COMPACT = 100
DISPLAY_TRUNCATION_LARGE = 500
DISPLAY_TRUNCATION_RESPONSE = 150
DISPLAY_TRUNCATION_ERROR = 80
DISPLAY_TRUNCATION_EVAL = 60
# --- Display top-N items ---
DISPLAY_TOP_N_TINY = 3
DISPLAY_TOP_N_MINI = 5
DISPLAY_TOP_N_BRIEF = 8
DISPLAY_TOP_N_SMALL = 10
DISPLAY_TOP_N_MEDIUM = 20
# --- Display misc ---
ANSWER_MAX_DISPLAY_LENGTH = 27
BENCHMARK_DISPLAY_LIMIT = 20
EIGENVALUE_DISPLAY_LIMIT = 20
HASH_DISPLAY_LENGTH = 8
MAX_TAGS_PER_BENCHMARK = 3
BAR_CHART_SCALE = 20
ROUNDING_PRECISION = 3
ROUNDING_PRECISION_FINE = 4
# --- CLI banner ---
BANNER_WIDTH = 64
WM_BRANDING_WIDTH = 48
# --- Progress logging intervals ---
PROGRESS_LOG_INTERVAL_10 = 10
PROGRESS_LOG_INTERVAL_20 = 20
# --- Visualization DPI ---
VIZ_DPI = 150
VIZ_DPI_STANDARD = 120
VIZ_DPI_LOW = 100
VIZ_PLOT_DPI = 300
# --- Visualization figure dimensions ---
VIZ_FIGURE_WIDTH_PX = 1000
VIZ_FIGURE_HEIGHT_PX = 800
# --- Visualization figure sizes ---
VIZ_FIGSIZE_STANDARD = (10, 8)
VIZ_FIGSIZE_WIDE = (10, 6)
VIZ_FIGSIZE_COMPACT = (8, 6)
VIZ_FIGSIZE_SUMMARY = (18, 18)
VIZ_FIGSIZE_DETAIL = (12, 10)
VIZ_FIGSIZE_MIN_WIDTH = 8
VIZ_FIGSIZE_MIN_HEIGHT = 4
VIZ_FIGSIZE_HEATMAP_SCALE_W = 0.5
VIZ_FIGSIZE_HEATMAP_SCALE_H = 0.8
VIZ_FIGSIZE_CONCEPT_MIN_W = 6
VIZ_FIGSIZE_CONCEPT_SCALE = 1.2
VIZ_GRID_SUMMARY_ROWS = 3
VIZ_GRID_SUMMARY_COLS = 3
# --- Visualization font sizes ---
VIZ_FONTSIZE_TINY = 7
VIZ_FONTSIZE_SMALL = 8
VIZ_FONTSIZE_ANNOTATION = 9
VIZ_FONTSIZE_BODY = 10
VIZ_FONTSIZE_TITLE = 11
VIZ_FONTSIZE_SUBTITLE = 12
VIZ_FONTSIZE_SUPTITLE = 14
# --- Visualization line widths ---
VIZ_LINEWIDTH_FINE = 0.5
VIZ_LINEWIDTH_HAIRLINE = 1
VIZ_LINEWIDTH_THIN = 0.8
VIZ_LINEWIDTH_NORMAL = 2
# --- Visualization alpha values ---
VIZ_ALPHA_LIGHT = 0.3
VIZ_ALPHA_HIST = 0.4
VIZ_ALPHA_HALF = 0.5
VIZ_ALPHA_MEDIUM = 0.6
VIZ_ALPHA_HIGH = 0.7
VIZ_HISTOGRAM_ALPHA = 0.5
VIZ_BBOX_ALPHA = 0.8
# --- Visualization marker sizes ---
VIZ_MARKER_SIZE_TINY = 10
VIZ_MARKER_SIZE_XS = 20
VIZ_MARKER_SIZE_SMALL = 30
VIZ_MARKER_SIZE_MOVEMENT = 40
VIZ_MARKER_SIZE = 50
VIZ_MARKER_SIZE_LARGE = 60
VIZ_MARKER_SIZE_XLARGE = 80
VIZ_X_MARKER_SIZE = 100
VIZ_CENTROID_MARKER_SIZE_ALT = 150
VIZ_CENTROID_MARKER_SIZE = 200
VIZ_HEATMAP_ASTERISK_SIZE = 200
VIZ_MARKERSIZE_LINE_SMALL = 6
VIZ_MARKERSIZE_LINE = 8
# --- Visualization colorbar ---
VIZ_COLORBAR_FRACTION = 0.046
VIZ_COLORBAR_PAD = 0.04
# --- Visualization suptitle offsets ---
VIZ_SUPTITLE_Y_OFFSET = 1.01
VIZ_SUPTITLE_Y_OFFSET_HIGH = 1.02
# --- Visualization heatmap ---
VIZ_HEATMAP_ACCURACY_VMIN = 0.5
VIZ_HEATMAP_ACCURACY_VMAX = 1.0
HEATMAP_TEXT_CONTRAST_THRESHOLD = 0.5
# --- Visualization histogram bins ---
VIZ_HISTOGRAM_BINS = 30
VIZ_HISTOGRAM_BINS_20 = 20
VIZ_HISTOGRAM_BINS_LARGE = 50
# --- Visualization positioning ---
VIZ_TEXT_BOX_LEFT = 0.02
VIZ_TEXT_BOX_RIGHT = 0.98
VIZ_CONTOURF_LEVEL = 0.5
VIZ_LEGEND_Y_TOP = 0.99
# --- Visualization mesh grids ---
VIZ_MESHGRID_RESOLUTION_HIGH = 200
VIZ_MESHGRID_RESOLUTION_MED = 100
# --- Visualization arrow properties ---
VIZ_ARROW_HEAD_LENGTH = 0.1
VIZ_ARROW_HEAD_WIDTH = 0.05
VIZ_ARROW_LINEWIDTH = 1.5
VIZ_ARROW_SIZE_DEFAULT = 1
# --- Visualization bar/direction ---
VIZ_MOVEMENT_SCALE = 0.8
VIZ_BAR_WIDTH = 0.35
VIZ_DIRECTION_N_PCA = 5
VIZ_DIRECTION_N_RANDOM_SEARCH = 10
VIZ_TRUTHFUL_REGION_THRESHOLD = 0.5
# --- Visualization scale ---
VIZ_MIN_SCALE = 0.1
VIZ_SCALE_PADDING = 0.8
# --- Visualization dimensionality reduction ---
VIZ_PCA_COMPONENTS = 50
VIZ_MAX_SAMPLES = 200
VIZ_PERPLEXITY = 30
VIZ_N_NEIGHBORS = 15
VIZ_MIN_DIST = 0.1
VIZ_N_NEIGHBORS_TRIMAP = 10
VIZ_NUM_ITERS = 50
VIZ_PCA_DIMS_TRIMAP = 30
VIZ_LIMIT = 200
TSNE_N_ITER = 1000
TSNE_PERPLEXITY_MAX = 30
# --- Visualization steering presets ---
VIZ_PROJECTION_COMPONENTS = 5
VIZ_REPLACEMENT_BLEND = 0.5
VIZ_MLP_EPOCHS = 100
VIZ_CLAMPING_MARGIN = 0.1
# --- Visualization gallery ---
VIZ_GALLERY_N_PER_TYPE = 2
# --- SAE top features display ---
SAE_TOP_FEATURES_DISPLAY = 15
SAE_TOP_FEATURES_MAX = 40
# --- Context preview ---
CONTEXT_MAX_PREVIEW = 1000
