"""WICHER (Whirlwind) steering method constants."""
from wisent.core.utils.constants.for_experiments.by_method.simple import *  # noqa: F401,F403

WICHER_CONCEPT_DIM = 0
OPTUNA_WICHER_CONCEPT_DIMS = (0, 8, 16)
OPTUNA_WICHER_STEPS_MIN = 1
OPTUNA_WICHER_STEPS_MAX = 5
