"""Domain-organized experiment constants (optimization, evaluation, geometry, analysis, infra)."""
from wisent.core.utils.constants.for_experiments.by_domain._optimization import *  # noqa: F401,F403
