"""OSTRZE (Blade) steering method constants."""
from wisent.core.utils.constants.for_experiments.by_method.simple._broyden import *  # noqa: F401,F403

OSTRZE_C = 1.0
OSTRZE_DEFAULT_ITERATIONS = 1000
MIN_PAIRS_OSTRZE = 20
