"""LM-eval extractor manifest - Part 2 (P-Z tasks)."""

base_import: str = "wisent.extractors.lm_eval.lm_task_extractors."

LM_EXTRACTORS_PART2: dict[str, str] = {
    "paws_x": f"{base_import}pawsx:PawsXExtractor",
    "paws-x": f"{base_import}pawsx:PawsXExtractor",
    "polemo2": f"{base_import}polemo2:Polemo2Extractor",
    "polemo2_in": f"{base_import}polemo2:Polemo2Extractor",
    "polemo2_out": f"{base_import}polemo2:Polemo2Extractor",
    "portuguese_bench": f"{base_import}portuguese_bench:PortugueseBenchExtractor",
    "realtoxicityprompts": f"{base_import}realtoxicityprompts:RealtoxicitypromptsExtractor",
    "ruler": f"{base_import}ruler:RulerExtractor",
    "ruler_cwe": f"{base_import}ruler:RulerExtractor",
    "ruler_fwe": f"{base_import}ruler:RulerExtractor",
    "ruler_qa_hotpot": f"{base_import}ruler:RulerExtractor",
    "ruler_qa_squad": f"{base_import}ruler:RulerExtractor",
    "ruler_vt": f"{base_import}ruler:RulerExtractor",
    "niah_single_1": f"{base_import}ruler:RulerExtractor",
    "niah_single_2": f"{base_import}ruler:RulerExtractor",
    "niah_single_3": f"{base_import}ruler:RulerExtractor",
    "niah_multikey_1": f"{base_import}ruler:RulerExtractor",
    "niah_multikey_2": f"{base_import}ruler:RulerExtractor",
    "niah_multikey_3": f"{base_import}ruler:RulerExtractor",
    "niah_multiquery": f"{base_import}ruler:RulerExtractor",
    "niah_multivalue": f"{base_import}ruler:RulerExtractor",
    "score": f"{base_import}score:ScoreExtractor",
    "prompt_robustness_agieval_aqua_rat": f"{base_import}agieval_aqua_rat:AgievalAquaRatExtractor",
    "option_order_robustness_agieval_aqua_rat": f"{base_import}agieval_aqua_rat:AgievalAquaRatExtractor",
    "non_greedy_robustness_agieval_aqua_rat": f"{base_import}agieval_aqua_rat:AgievalAquaRatExtractor",
    "option_order_robustness_agieval_logiqa_en": f"{base_import}score:ScoreExtractor",
    "option_order_robustness_agieval_lsat_ar": f"{base_import}score:ScoreExtractor",
    "option_order_robustness_agieval_lsat_lr": f"{base_import}score:ScoreExtractor",
    "option_order_robustness_agieval_lsat_rc": f"{base_import}score:ScoreExtractor",
    "option_order_robustness_agieval_sat_en": f"{base_import}score:ScoreExtractor",
    "option_order_robustness_agieval_sat_math": f"{base_import}score:ScoreExtractor",
    "score_non_greedy_robustness_mmlu_pro": f"{base_import}score:ScoreExtractor",
    "score_option_order_robustness_mmlu_pro": f"{base_import}score:ScoreExtractor",
    "score_prompt_robustness_mmlu_pro": f"{base_import}score:ScoreExtractor",
    "scrolls": f"{base_import}scrolls:ScrollsExtractor",
    "scrolls_contractnli": f"{base_import}scrolls:ScrollsExtractor",
    "scrolls_govreport": f"{base_import}scrolls:ScrollsExtractor",
    "scrolls_narrativeqa": f"{base_import}scrolls:ScrollsExtractor",
    "scrolls_qasper": f"{base_import}scrolls:ScrollsExtractor",
    "scrolls_qmsum": f"{base_import}scrolls:ScrollsExtractor",
    "scrolls_quality": f"{base_import}scrolls:ScrollsExtractor",
    "scrolls_summscreenfd": f"{base_import}scrolls:ScrollsExtractor",
    "simple_cooccurrence_bias": f"{base_import}simple_cooccurrence_bias:SimpleCooccurrenceBiasExtractor",
    "siqa": f"{base_import}siqa:SIQAExtractor",
    "siqa_ca": f"{base_import}siqa:SIQAExtractor",
    "spanish_bench": f"{base_import}spanish_bench:SpanishBenchExtractor",
    "squad_completion": f"{base_import}squad_completion:SquadCompletionExtractor",
    "storycloze": f"{base_import}storycloze:StoryclozeExtractor",
    "super_glue": f"{base_import}super_glue:SuperGlueExtractor",
    # Okapi multilingual benchmarks (157 tasks - arc, hellaswag, mmlu, truthfulqa)
    # Noreval Norwegian benchmarks (63 tasks - generation and multiple-choice)
    # Generation tasks (38 tasks)
    "ask_gec": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "ask_gec_p0": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "ask_gec_p1": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "ask_gec_p2": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "ask_gec_p3": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "ask_gec_p4": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "norquad": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "norquad_p0": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "norquad_p1": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "norquad_p2": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "norquad_p3": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "norquad_p4": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "norrewrite_instruct": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    "norsummarize_instruct": f"{base_import}noreval_gen:NorevalGenerationExtractor",
    # Multiple choice tasks (25 tasks)
    "ncb": f"{base_import}noreval_mc:NorevalMultipleChoiceExtractor",
    "swde": f"{base_import}swde:SwdeExtractor",
    "tinybenchmarks": f"{base_import}tinybenchmarks:TinybenchmarksExtractor",
    "tinyBenchmarks": f"{base_import}tinybenchmarks:TinybenchmarksExtractor",
    "tmmluplus": f"{base_import}tmmluplus:TmmluplusExtractor",
    "toxigen": f"{base_import}toxigen:ToxigenExtractor",
    "translation": f"{base_import}translation:TranslationExtractor",
    "gpt3_translation_benchmarks": f"{base_import}translation:TranslationExtractor",
    "turblimp_core": f"{base_import}turblimp_core:TurblimpCoreExtractor",
    "unitxt": f"{base_import}unitxt:UnitxtExtractor",
    "unscramble": f"{base_import}unscramble:UnscrambleExtractor",
    "winogender": f"{base_import}winogender:WinogenderExtractor",
    "wmdp": f"{base_import}wmdp:WmdpExtractor",
    "wsc273": f"{base_import}wsc273:Wsc273Extractor",
    "xcopa": f"{base_import}xcopa:XcopaExtractor",
    "xquad": f"{base_import}xquad:XquadExtractor",
    "zhoblimp": f"{base_import}zhoblimp:ZhoblimpExtractor",
    # NEW: Auto-generated extractors for missing task families
    "arabic": f"{base_import}arabic:ArabicExtractor",
    "afrixnli": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_amh": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_eng": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_ewe": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_fra": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_hau": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_ibo": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_kin": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_lin": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_lug": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_orm": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_sna": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_sot": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_swa": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_twi": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_wol": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_xho": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_yor": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrixnli_en_direct_zul": f"{base_import}afrixnli:AfrixnliExtractor",
    "afrimgsm": f"{base_import}afrimgsm:AfrimgsmExtractor",
    "afrimgsm_amh_prompt_1": f"{base_import}afrimgsm:AfrimgsmExtractor",
    "ceval_valid": f"{base_import}ceval_valid:CevalValidExtractor",
    "advanced": f"{base_import}advanced:AdvancedExtractor",
    "afrimmlu": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_amh_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_eng_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_ewe_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_fra_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_hau_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_ibo_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_kin_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_lin_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_lug_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_orm_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_sna_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_sot_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_swa_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_twi_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_wol_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_xho_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_yor_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "afrimmlu_direct_zul_prompt_1": f"{base_import}afrimmlu:AfrimmluExtractor",
    "paws": f"{base_import}paws:PawsExtractor",
    "ja": f"{base_import}ja:JaExtractor",
    "super": f"{base_import}super:SuperExtractor",
    "option": f"{base_import}option:OptionExtractor",
    "codexglue": f"{base_import}codexglue:CodexglueExtractor",
    "phrases": f"{base_import}phrases:PhrasesExtractor",
    "phrases_es": f"{base_import}phrases:PhrasesExtractor",
    "phrases_es-va": f"{base_import}phrases:PhrasesExtractor",
    "phrases_va": f"{base_import}phrases:PhrasesExtractor",
    "phrases_va-ca": f"{base_import}phrases:PhrasesExtractor",
    "phrases_va-es": f"{base_import}phrases:PhrasesExtractor",
    "code2text": f"{base_import}code_x_glue:Code2TextExtractor",
    "ethics": f"{base_import}ethics:EthicsExtractor",
    "cabreu": f"{base_import}cabreu:CabreuExtractor",
    "sycophancy": f"{base_import}sycophancy:SycophancyExtractor",
    "sycophancy_on_nlp_survey": f"{base_import}sycophancy:SycophancyExtractor",
    "sycophancy_on_philpapers2020": f"{base_import}sycophancy:SycophancyExtractor",
    "sycophancy_on_political_typology_quiz": f"{base_import}sycophancy:SycophancyExtractor",
    "evalita_sp": f"{base_import}evalita_sp:EvalitaSpExtractor",
    "flan": f"{base_import}flan:FlanExtractor",
    "assin": f"{base_import}assin:AssinExtractor",
    "assin_entailment": f"{base_import}assin:AssinExtractor",
    "gsm": f"{base_import}gsm:GsmExtractor",
    "mnli": f"{base_import}mnli:MnliExtractor",
    "tinytruthfulqa": f"{base_import}tinytruthfulqa:TinytruthfulqaExtractor",
    "tinyTruthfulQA": f"{base_import}tinytruthfulqa:TinytruthfulqaExtractor",
    "tinyTruthfulQA_mc1": f"{base_import}tinytruthfulqa:TinytruthfulqaExtractor",
    "t0": f"{base_import}t0:T0Extractor",
    "tag": f"{base_import}tag:TagExtractor",
    "basque_glue": f"{base_import}basque_glue:BasqueGlueExtractor",
    "basque-glue": f"{base_import}basque_glue:BasqueGlueExtractor",  # Hyphenated alias
    "chain": f"{base_import}chain:ChainExtractor",
    "gpt3": f"{base_import}gpt3:Gpt3Extractor",
    "math": f"{base_import}math:MathExtractor",
    "math500": f"{base_import}math:MathExtractor",
    "polymath_en_medium": f"{base_import}polymath:PolymathExtractor",
    "polymath_zh_medium": f"{base_import}polymath:PolymathExtractor",
    "polymath_en_high": f"{base_import}polymath:PolymathExtractor",
    "polymath_zh_high": f"{base_import}polymath:PolymathExtractor",
    "livemathbench_cnmo_en": f"{base_import}livemathbench:LivemathbenchExtractor",
    "livemathbench_cnmo_zh": f"{base_import}livemathbench:LivemathbenchExtractor",
    "self": f"{base_import}self:SelfExtractor",
    "twenty_newsgroups": f"{base_import}twenty_newsgroups:TwentyNewsgroupsExtractor",
    "20_newsgroups": f"{base_import}unitxt:UnitxtExtractor",
    "ag": f"{base_import}ag:AgExtractor",
    "ag_news": f"{base_import}unitxt:UnitxtExtractor",
    "anagrams1": f"{base_import}anagrams1:Anagrams1Extractor",
    "anagrams2": f"{base_import}anagrams2:Anagrams2Extractor",
    "argument": f"{base_import}argument:ArgumentExtractor",
    "argument_topic": f"{base_import}unitxt:UnitxtExtractor",
    "bhtc": f"{base_import}bhtc:BhtcExtractor",
    "catalanqa": f"{base_import}catalanqa:CatalanqaExtractor",
    "catcola": f"{base_import}catcola:CatcolaExtractor",
    "claim": f"{base_import}claim:ClaimExtractor",
    "claim_stance_topic": f"{base_import}unitxt:UnitxtExtractor",
    "cnn": f"{base_import}cnn:CnnExtractor",
    "cocoteros": f"{base_import}cocoteros:CocoterosExtractor",
    "coedit": f"{base_import}coedit:CoeditExtractor",
    "cola": f"{base_import}cola:ColaExtractor",
    "commonsense": f"{base_import}commonsense:CommonsenseExtractor",
    "coqcat": f"{base_import}coqcat:CoqcatExtractor",
    "cycle": f"{base_import}cycle:CycleExtractor",
    "dbpedia": f"{base_import}dbpedia:DbpediaExtractor",
    "doc": f"{base_import}doc:DocExtractor",
    "epec": f"{base_import}epec:EpecExtractor",
    "eq": f"{base_import}eq:EqExtractor",
    "escola": f"{base_import}escola:EscolaExtractor",
    "ethos": f"{base_import}ethos:EthosExtractor",
    "fda": f"{base_import}fda:FdaExtractor",
    "financial": f"{base_import}financial:FinancialExtractor",
    "galcola": f"{base_import}galcola:GalcolaExtractor",
    "law": f"{base_import}law:LawExtractor",
    "medical": f"{base_import}medical:MedicalExtractor",
    "parafraseja": f"{base_import}parafraseja:ParafrasejaExtractor",
    "parafrases": f"{base_import}parafrases:ParafrasesExtractor",
    "qnlieu": f"{base_import}qnlieu:QnlieuExtractor",
    "random": f"{base_import}random:RandomExtractor",
    "reversed": f"{base_import}reversed:ReversedExtractor",
    "sglue": f"{base_import}sglue:SglueExtractor",
    "sglue_rte": f"{base_import}sglue_rte:SglueRteExtractor",
    "summarization": f"{base_import}summarization:SummarizationExtractor",
    "teca": f"{base_import}teca:TecaExtractor",
    "tinyarc": f"{base_import}tinyarc:TinyarcExtractor",
    "tinyArc": f"{base_import}tinyarc:TinyarcExtractor",
    "tinygsm8k": f"{base_import}tinygsm8k:Tinygsm8kExtractor",
    "tinyGSM8k": f"{base_import}tinygsm8k:Tinygsm8kExtractor",
    "tinyhellaswag": f"{base_import}tinyhellaswag:TinyhellaswagExtractor",
    "tinyHellaswag": f"{base_import}tinyhellaswag:TinyhellaswagExtractor",
    "tinymmlu": f"{base_import}tinymmlu:TinymmluExtractor",
    "tinyMMLU": f"{base_import}tinymmlu:TinymmluExtractor",
    "tinywinogrande": f"{base_import}tinywinogrande:TinywinograndeExtractor",
    "tinyWinogrande": f"{base_import}tinywinogrande:TinywinograndeExtractor",
    "unfair": f"{base_import}unitxt:UnitxtExtractor",
    "unfair_tos": f"{base_import}unitxt:UnitxtExtractor",
    "vaxx": f"{base_import}vaxx:VaxxExtractor",
    "vaxx_stance": f"{base_import}vaxx:VaxxExtractor",
    "xlsum": f"{base_import}xlsum:XlsumExtractor",
    "yahoo_answers_topics": f"{base_import}unitxt:UnitxtExtractor",
    "humaneval_instruct": f"{base_import}instructhumaneval:InstructhumanevalExtractor",
    "humaneval_64_instruct": f"{base_import}instructhumaneval:InstructhumanevalExtractor",
    "apps": f"{base_import}apps:AppsExtractor",
    "recode": f"{base_import}recode:RecodeExtractor",
    "conala": f"{base_import}conala:ConalaExtractor",
    "concode": f"{base_import}concode:ConcodeExtractor",
    "mercury": f"{base_import}mercury:MercuryExtractor",
    # Note: WMT14 and WMT16 translation tasks are now in group_task_manifests/
}
